import React, { FC } from 'react';

/**
 * Propriétés pour le Boutton
 */
export interface ButtonProps {
    /**
     * Contenue
     */
    children?: any;
    /**
     * Variante (couleur)
     */
    variation?: 'normal' | 'primary' | 'success';
    /**
     * Affiche une bordure
     */
    bordered?: boolean;
    /**
     * Désactive le boutton
     */
    disabled?: boolean;
    /**
     * Handler appelé quand le boutton est clické
     */
    onClick?: React.MouseEventHandler<HTMLButtonElement>;
}

/**
 * Propriétés par défault pour le boutton
 */
const defaultProps: ButtonProps = {
    variation: 'primary',
    bordered: false,
    disabled: false
};

/**
 * Boutton
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const Button: FC<ButtonProps> = ({ children, variation, bordered, disabled, onClick }: ButtonProps) => {
    return (
        <button
            onClick={onClick}
            className={
                'component__button component__button__' +
                variation +
                (bordered ? ' component__button__bordered' : '') +
                (disabled ? ' component__button__disabled' : '')
            }
            disabled={disabled}
        >
            {children}
        </button>
    );
};

Button.defaultProps = defaultProps;
