import React, { FC } from 'react';
import { useSelector } from 'react-redux';
import { EndEffect } from '../models/PlayableCard';
import { calcScore } from '../models/score';
import { AppState } from '../store/reducer';
import { Button } from './Button';
import { BottomBar, BottomBarContainer, BottomBarRight } from './containers/BottomBar';
import { PlayContainer, PlayContainerBot, PlayContainerMid, PlayContainerTop } from './containers/PlayContainer';
import { StatsDisplay } from './StatsDisplay';

/**
 * Propriétés de l'écran de fin
 */
export interface EndRunScreenProps {
    run: number;
    effects: EndEffect[];
}

/**
 * Écran de fin
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const EndRunScreen: FC<EndRunScreenProps> = ({ run, effects }: EndRunScreenProps) => {
    const stats = useSelector((state: AppState) => state.stats);
    const runScore = calcScore(effects, stats.reputation);
    return (
        <PlayContainer>
            <PlayContainerTop>
                <div
                    style={{
                        fontWeight: 'bold',
                        fontSize: '24px',
                        height: '100%',
                        display: 'flex',
                        alignItems: 'center',
                        justifyContent: 'center'
                    }}
                >
                    Résultats de la Course #{run}
                </div>
            </PlayContainerTop>
            <PlayContainerMid>
                <div style={{ display: 'flex', justifyContent: 'center' }}>
                    <div style={{ width: '45%' }}>
                        <StatsDisplay effects={effects} score={runScore} />
                    </div>
                </div>
            </PlayContainerMid>
            <PlayContainerBot>
                <BottomBar>
                    <BottomBarContainer>
                        <BottomBarRight>
                            <Button bordered={false} variation="success">
                                Continuer
                            </Button>
                        </BottomBarRight>
                    </BottomBarContainer>
                </BottomBar>
            </PlayContainerBot>
        </PlayContainer>
    );
};
