import React, { FC } from 'react';
import { EffectTranslations, EndEffect } from '../models/PlayableCard';
import { Progress } from './containers/TopBar';

/**
 * Propriétés pour la progress bar de la stat
 */
export interface StatsProgressProps {
    /**
     * Effet à afficher
     */
    effect: EndEffect;
}

/**
 * Barre de progression d'affiche d'un effet
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const StatsProgress: FC<StatsProgressProps> = ({ effect }: StatsProgressProps) => {
    return (
        <div
            style={{
                display: 'flex',
                marginBottom: '1rem',
                marginLeft: '1em',
                marginRight: '1em'
            }}
        >
            <div style={{ width: '35%' }}>{EffectTranslations[effect.name]}</div>
            <div style={{ width: '65%' }}>
                <Progress
                    percent={((effect.value + (effect.name === 'difficulty' ? 120 : 0)) / (effect.max + (effect.name === 'difficulty' ? 200 : 0))) * 100}
                    variant={effect.name}
                />
            </div>
        </div>
    );
};

/**
 * Propriétés de l'affichage des stats
 */
export interface StatsDisplayProps {
    /**
     * Effets à afficher
     */
    effects: EndEffect[];
    /**
     * Score à afficher
     */
    score: number;
}

/**
 * Affichage des stats
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const StatsDisplay: FC<StatsDisplayProps> = ({ effects, score }: StatsDisplayProps) => {
    return (
        <>
            {effects.map((val: EndEffect, index: number) => {
                return <StatsProgress key={index} effect={val} />;
            })}
            <div
                style={{
                    display: 'flex',
                    marginBottom: '1rem',
                    marginTop: '3rem',
                    marginLeft: '1em',
                    marginRight: '1em'
                }}
            >
                <div style={{ width: '35%' }}>Score</div>
                <div style={{ width: '65%' }}>
                    <Progress percent={(score + 1) * 50} variant="score" />
                </div>
            </div>
        </>
    );
};
