import React, { FC } from 'react';

/**
 * Propriétés pour la Card
 */
export interface CardProp {
    /**
     * Contenue de la carte
     */
    children?: any;

    /**
     * True si la carte est un placeholder
     */
    placeholder?: boolean;

    /**
     * Handler de click sur la carte
     */
    onClick?: React.MouseEventHandler<HTMLDivElement>;
}

/**
 * Propriétés par défault pour la Card
 */
const defaultProps: CardProp = {
    placeholder: false
};

/**
 * Vue d'une carte
 * @param props Propriétés du composant
 * @returns Contenue du composant (jsx)
 */
export const Card: FC<CardProp> = ({ children, placeholder, onClick }: CardProp) => {
    return (
        <div onClick={onClick} className={'component__card' + (placeholder ? ' component__card__placeholder' : '')}>
            {children}
        </div>
    );
};

Card.defaultProps = defaultProps;

/**
 * Propriétés pour le titre de la carte
 */
export interface CardTitleProp {
    /**
     * Contenue
     */
    children?: any;
}

/**
 * Titre d'une carte
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const CardTitle: FC<CardTitleProp> = ({ children }: CardTitleProp) => {
    return <span className="component__card__title">{children}</span>;
};

/**
 * Propriétés pour l'icon d'une carte
 */
export interface CardIconProp {
    /**
     * Source de l'icon
     */
    src?: string;
    /**
     * Texte alternatif de l'icon
     */
    alt?: string;
}

/**
 * Icone d'une carte
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const CardIcon: FC<CardIconProp> = ({ src, alt }: CardIconProp) => {
    return <img src={src} alt={alt} className="component__card__image" />;
};

/**
 * Propriétés de la description de la carte
 */
export interface CardDescriptionProp {
    /**
     * Contenue
     */
    children?: any;
}

/**
 * Description de la carte
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const CardDescription: FC<CardIconProp> = ({ children }: CardDescriptionProp) => {
    return <span className="component__card__description">{children}</span>;
};
