import React, { Children, FC } from 'react';
import { Card } from './Card';

/**
 * Propriétés de l'espace de jeu
 */
export interface PlaygroundProp {
    /**
     * Contenue
     */
    children?: any;
    /**
     * Nombre maximum d'enfants
     */
    cards_count: number;
}

/**
 * Propriétés par défault de l'espace de jeu
 */
const defaultProps: PlaygroundProp = {
    cards_count: 3
};

/**
 * Espace de jeu central
 * @param props Propriétés
 * @returns Contenue (jsx)
 */
export const Playground: FC<PlaygroundProp> = ({ children, cards_count }: PlaygroundProp) => {
    const cards: JSX.Element[] = [];
    const placedCards: any[] = Children.toArray(children);

    for (let i: number = 0; i < cards_count; i++) {
        if (i < placedCards.length) {
            cards.push(React.cloneElement(placedCards[i], { key: i }));
        } else {
            cards.push(<Card key={i} placeholder></Card>);
        }
    }

    return (
        <div className="component__playground">
            <div className="component__playground__container">{cards}</div>
        </div>
    );
};

Playground.defaultProps = defaultProps;
