/**
 * Nom de l'effet
 */
export type EffectName = 'danger' | 'difficulty' | 'reputation';

/**
 * Traduction des effets en chaines affichables
 */
export type EffectTranslation = { [name in EffectName]: string };

/**
 * Traduction des effets en chaines affichables
 */
export const EffectTranslations: EffectTranslation = {
    danger: 'Danger',
    difficulty: 'Difficulté',
    reputation: 'Réputation'
};

/**
 * Effets résultants d'une course
 */
export interface Effect {
    /**
     * Nom de l'effet
     */
    name: EffectName;
    /**
     * Valeur de l'effet
     */
    value: number;
}

/**
 * Effets résultants d'une course, utilisés à la fin de la partie pour le calcul de score
 */
export interface EndEffect extends Effect {
    /**
     * Valeur maximale de l'effet
     */
    max: number;
}

/**
 * Nom des effets nécessaire au débloquage d'une carte
 */
export type RequirementName = 'run' | 'reputation';

/**
 * Effet nécessaire au débloquage d'une carte ou d'une section
 */
export interface Requirement {
    /**
     * Nom de la dépendance
     */
    name: RequirementName;
    /**
     * Valeur minimale pour débloquer la carte
     */
    value: number;
}

/**
 * Carte jouable
 */
export interface PlayableCard {
    /**
     * Identifiant unique
     */
    id: number;
    /**
     * Nom de la carte
     */
    name: string;
    /**
     * Image d'illustration
     */
    image?: string;
    /**
     * Description de la carte
     */
    description: string;
    /**
     * Effets que la carte engendre
     */
    effects: Effect[];
    /**
     * Dépendances pour débloquer la carte
     */
    requirements?: Requirement[];
}

/**
 * Séction de cartes
 */
export interface CardSection {
    /**
     * Identifiant unique
     */
    id: number;
    /**
     * Nom de la section
     */
    name: string;
    /**
     * Cartes contenues dans la section
     */
    cards: PlayableCard[];
    /**
     * Nombre de cartes à choisir dans la section
     */
    count: number;
    /**
     * Dépendences au débloquage de la section
     */
    requirements?: Requirement[];
}

/**
 * Liste de toutes les sections de cartes jouables
 */
export type CardSelection = CardSection[];
