import { CardSection, CardSelection, PlayableCard } from './PlayableCard';
import { Stats } from './Stats';

/**
 * Filtre les cartes en fonction de leurs dépendences et de l'état actuel du jeu
 * @param cards Cartes à filtrer
 * @param stats Statistiques actuels du joueur
 * @returns Cartes filtrés
 */
export const filterCards = (cards: CardSelection, stats: Stats): CardSelection => {
    let copy = JSON.parse(JSON.stringify(cards)) as CardSelection;

    copy = copy.filter((cat: CardSection) => {
        for (const req of cat.requirements ?? []) {
            if (stats[req.name] < req.value) {
                return false;
            }
        }
        return true;
    });

    copy.forEach((cat: CardSection) => {
        cat.cards = cat.cards.filter((card: PlayableCard, index: number) => {
            for (const req of card.requirements ?? []) {
                if (stats[req.name] < req.value) {
                    return false;
                }
            }
            return true;
        });
    });

    return copy;
};
