import { EndEffect } from './PlayableCard';

/**
 * Calcule le score d'une course
 * @param effects Effets de la course
 * @param currentRep Réputation actuelle
 * @returns Score, entre -1 et 1
 */
export const calcScore = (effects: EndEffect[], currentRep: number): number => {
    const danger: EndEffect = effects.find((e) => e.name === 'danger') as EndEffect;
    const difficulty: EndEffect = effects.find((e) => e.name === 'difficulty') as EndEffect;
    const reputation: EndEffect = effects.find((e) => e.name === 'reputation') as EndEffect;

    const diff = (difficulty.value + 69) / 240;
    const r = Math.max(Math.min(reputation.value + currentRep, 500), 0) / 500;
    const base = -200 * (r + 0.05) * (diff - r) * (diff - r) + r;
    const lowbonus = Math.min((1 - r) / 2, 1);
    const dangermalus = (danger.value / 80) * (-4 * (r - 0.5) * (r - 0.5) + 1);

    return Math.min(Math.max(base - dangermalus + lowbonus, -1), 1) + 0.1;
};
