import React, { FC, useEffect, useState } from 'react';
import { useSelector } from 'react-redux';
import { useNavigate } from 'react-router';
import { Transition } from 'react-transition-group';
import { Button } from '../components/Button';
import { BottomBar, BottomBarContainer, BottomBarRight } from '../components/containers/BottomBar';
import { PlayContainer, PlayContainerBot, PlayContainerMid, PlayContainerTop } from '../components/containers/PlayContainer';
import { Progress } from '../components/containers/TopBar';
import { Progression } from '../components/Progression';
import { AppState, Run } from '../store/reducer';

/**
 * Page d'affichage des résultats de la partie
 * @returns Contenue (jsx)
 */
export const Done: FC = () => {
    const runs = useSelector((state: AppState) => state.runs);
    const globalPop = useSelector((state: AppState) => state.stats.reputation);
    const navigate = useNavigate();
    const [show, setShow] = useState<boolean>(false);

    const duration = 500;

    const defaultStyle: React.CSSProperties = {
        transition: `opacity ${duration}ms ease-in-out`,
        opacity: 0
    };

    const transitionStyles: { [index: string]: React.CSSProperties } = {
        entering: { opacity: 1 },
        entered: { opacity: 1 },
        exiting: { opacity: 0 },
        exited: { opacity: 0 }
    };

    const goNext = () => {
        navigate('/menu');
    };

    useEffect(() => {
        setTimeout(() => setShow(true), 0);
    }, []);

    return (
        <Transition in={show} timeout={duration} onExited={() => goNext()}>
            {(state) => (
                <div
                    style={{
                        ...defaultStyle,
                        ...transitionStyles[state]
                    }}
                >
                    <PlayContainer>
                        <PlayContainerTop>
                            <div
                                style={{
                                    fontWeight: 'bold',
                                    fontSize: '24px',
                                    height: '100%',
                                    display: 'flex',
                                    alignItems: 'center',
                                    justifyContent: 'center'
                                }}
                            >
                                Résultats de la Partie
                            </div>
                        </PlayContainerTop>
                        <PlayContainerMid>
                            <div
                                style={{
                                    display: 'flex',
                                    alignItems: 'center',
                                    flexDirection: 'column',
                                    height: '100%'
                                }}
                            >
                                <Progression runs={runs} />
                                <div style={{ fontSize: '32px', marginTop: '1em', marginBottom: '0.5em' }}>
                                    {(() => {
                                        if (globalPop < 100) {
                                            return '...';
                                        } else if (globalPop < 300) {
                                            return 'Dommage';
                                        } else if (globalPop < 400) {
                                            return 'Presque';
                                        } else if (globalPop < 500) {
                                            return 'Encore un petit effort !';
                                        } else {
                                            return 'Bravo !';
                                        }
                                    })()}
                                </div>
                                <div style={{ width: '20vw' }}>
                                    <Progress percent={globalPop / 5} />
                                </div>
                                <div style={{ fontSize: '32px', marginTop: '0.5em', marginBottom: '0.5em' }}>{Math.round(globalPop)}/500</div>
                                {runs.map((run: Run, index: number) => {
                                    return (
                                        <div
                                            key={index}
                                            style={{ display: 'flex', justifyContent: 'center', flexDirection: 'row', width: '20vw', marginTop: '1em' }}
                                        >
                                            <div style={{ width: '35%' }}>Course #{index + 1}</div>
                                            <div style={{ width: '65%' }}>
                                                <Progress percent={((run?.score ?? -1) + 1) * 50} variant="score" />
                                            </div>
                                        </div>
                                    );
                                })}
                            </div>
                        </PlayContainerMid>
                        <PlayContainerBot>
                            <BottomBar>
                                <BottomBarContainer>
                                    <BottomBarRight>
                                        <Button bordered={false} variation="success" onClick={() => setShow(false)}>
                                            Rejouer
                                        </Button>
                                    </BottomBarRight>
                                </BottomBarContainer>
                            </BottomBar>
                        </PlayContainerBot>
                    </PlayContainer>
                </div>
            )}
        </Transition>
    );
};
