import React, { FC, useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useNavigate } from 'react-router';
import { Transition } from 'react-transition-group';
import { Button } from '../components/Button';
import { BottomBar, BottomBarContainer, BottomBarRight } from '../components/containers/BottomBar';
import { PlayContainer, PlayContainerBot, PlayContainerMid, PlayContainerTop } from '../components/containers/PlayContainer';
import { StatsDisplay } from '../components/StatsDisplay';
import { calcScore } from '../models/score';
import { AppState } from '../store/reducer';

/**
 * Page d'affichage des résultats de la course
 * @returns Contenue (jsx)
 */
export const End: FC = () => {
    const run = useSelector((state: AppState) => state.stats.run);
    const maxRun = useSelector((state: AppState) => state.runs.length);
    const reputation = useSelector((state: AppState) => state.stats.reputation);
    const effects = useSelector((state: AppState) => state.current_effects);
    const runScore = calcScore(effects, reputation);
    const dispatch = useDispatch();
    const navigate = useNavigate();
    const [show, setShow] = useState<boolean>(false);
    const [done, setDone] = useState<boolean>(false);

    const duration = 500;

    const defaultStyle: React.CSSProperties = {
        transition: `opacity ${duration}ms ease-in-out`,
        opacity: 0
    };

    const transitionStyles: { [index: string]: React.CSSProperties } = {
        entering: { opacity: 1 },
        entered: { opacity: 1 },
        exiting: { opacity: 0 },
        exited: { opacity: 0 }
    };

    const goNext = () => {
        dispatch({ type: 'stats/run', score: runScore });
        dispatch({ type: 'state/reputation', reputation: runScore * (effects.filter((e) => e.name === 'reputation')[0]?.value ?? 0) });
        if (done) {
            navigate('/done');
        } else {
            navigate('/start');
        }
    };

    useEffect(() => {
        setTimeout(() => setShow(true), 0);
    }, []);

    return (
        <Transition in={show} timeout={duration} onExited={() => goNext()}>
            {(state) => (
                <div
                    style={{
                        ...defaultStyle,
                        ...transitionStyles[state]
                    }}
                >
                    <PlayContainer>
                        <PlayContainerTop>
                            <div
                                style={{
                                    fontWeight: 'bold',
                                    fontSize: '24px',
                                    height: '100%',
                                    display: 'flex',
                                    alignItems: 'center',
                                    justifyContent: 'center'
                                }}
                            >
                                Résultats de la Course #{run + 1}
                            </div>
                        </PlayContainerTop>
                        <PlayContainerMid>
                            <div style={{ display: 'flex', justifyContent: 'center' }}>
                                <div style={{ width: '45%' }}>
                                    <StatsDisplay effects={effects} score={runScore} />
                                </div>
                            </div>
                        </PlayContainerMid>
                        <PlayContainerBot>
                            <BottomBar>
                                <BottomBarContainer>
                                    <BottomBarRight>
                                        {run + 1 < maxRun ? (
                                            <Button bordered={false} variation="success" onClick={() => setShow(false)}>
                                                Course suivante
                                            </Button>
                                        ) : (
                                            <Button
                                                bordered={false}
                                                variation="success"
                                                onClick={() => {
                                                    setDone(true);
                                                    setShow(false);
                                                }}
                                            >
                                                Suivant
                                            </Button>
                                        )}
                                    </BottomBarRight>
                                </BottomBarContainer>
                            </BottomBar>
                        </PlayContainerBot>
                    </PlayContainer>
                </div>
            )}
        </Transition>
    );
};
