import React, { FC, useEffect, useState } from 'react';
import { useNavigate } from 'react-router';
import { Transition } from 'react-transition-group';

export const Intro: FC = () => {
    const duration = 1000;

    const defaultStyle: React.CSSProperties = {
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        flexDirection: 'column',
        height: '100vh',
        transition: `opacity ${duration}ms ease-in-out`,
        opacity: 0
    };

    const transitionStyles: { [index: string]: React.CSSProperties } = {
        entering: { opacity: 1 },
        entered: { opacity: 1 },
        exiting: { opacity: 0 },
        exited: { opacity: 0 }
    };

    const navigate = useNavigate();
    const [show, setShow] = useState<boolean>(false);

    useEffect(() => {
        setTimeout(() => setShow(true), 0);
        setTimeout(() => setShow(false), 2500);
    }, []);

    return (
        <Transition
            in={show}
            timeout={duration}
            onExited={() => {
                navigate('/menu');
            }}
        >
            {(state) => (
                <div
                    style={{
                        ...defaultStyle,
                        ...transitionStyles[state]
                    }}
                >
                    <div style={{ fontSize: '72px' }}>Le Jeu™</div>
                </div>
            )}
        </Transition>
    );
};
