import React, { FC, useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { useNavigate } from 'react-router-dom';
import { Transition } from 'react-transition-group';
import { Button } from '../components/Button';

/**
 * Menue du jeu
 * @returns Contenue (jsx)
 */
export const Menu: FC = () => {
    const dispatch = useDispatch();

    const duration = 500;

    const defaultStyle: React.CSSProperties = {
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        flexDirection: 'column',
        height: '100vh',
        transition: `opacity ${duration}ms ease-in-out`,
        opacity: 0
    };

    const transitionStyles: { [index: string]: React.CSSProperties } = {
        entering: { opacity: 1 },
        entered: { opacity: 1 },
        exiting: { opacity: 0 },
        exited: { opacity: 0 }
    };

    const navigate = useNavigate();
    const [show, setShow] = useState<boolean>(false);

    useEffect(() => {
        setTimeout(() => setShow(true), 0);
    }, []);

    return (
        <Transition
            in={show}
            timeout={duration}
            onExited={() => {
                navigate('/start');
            }}
        >
            {(state) => (
                <div
                    style={{
                        ...defaultStyle,
                        ...transitionStyles[state]
                    }}
                >
                    <div style={{ fontSize: '72px', marginBottom: '1em' }}>XTremTrail</div>
                    <div style={{ marginTop: '3em' }}>
                        <Button
                            bordered={false}
                            variation="success"
                            onClick={() => {
                                dispatch({ type: 'stats/reset' });
                                setShow(false);
                            }}
                        >
                            Jouer
                        </Button>
                    </div>
                </div>
            )}
        </Transition>
    );
};
