import { useEffect, useState } from 'react';
import { useSelector } from 'react-redux';
import { useNavigate } from 'react-router';
import { Transition } from 'react-transition-group';
import { Button } from '../components/Button';
import { BottomBar, BottomBarContainer, BottomBarRight } from '../components/containers/BottomBar';
import { PlayContainer, PlayContainerBot, PlayContainerMid } from '../components/containers/PlayContainer';
import { Progress } from '../components/containers/TopBar';
import { Progression } from '../components/Progression';
import { AppState } from '../store/reducer';

export const Start = () => {
    const navigate = useNavigate();
    const run = useSelector((state: AppState) => state.stats.run);
    const runs = useSelector((state: AppState) => state.runs);
    const globalPop = useSelector((state: AppState) => state.stats.reputation);

    const duration = 500;

    const defaultStyle: React.CSSProperties = {
        transition: `opacity ${duration}ms ease-in-out`,
        opacity: 0
    };

    const transitionStyles: { [index: string]: React.CSSProperties } = {
        entering: { opacity: 1 },
        entered: { opacity: 1 },
        exiting: { opacity: 0 },
        exited: { opacity: 0 }
    };

    const [show, setShow] = useState<boolean>(false);

    useEffect(() => {
        setTimeout(() => setShow(true), 0);
    }, []);

    return (
        <Transition in={show} timeout={duration} onExited={() => navigate('/game')}>
            {(state) => (
                <div
                    style={{
                        ...defaultStyle,
                        ...transitionStyles[state]
                    }}
                >
                    <PlayContainer>
                        <PlayContainerMid>
                            <div
                                style={{
                                    display: 'flex',
                                    justifyContent: 'center',
                                    alignItems: 'center',
                                    flexDirection: 'column',
                                    height: '100%'
                                }}
                            >
                                <div style={{ fontSize: '72px', marginBottom: '1em' }}>Course #{run + 1}</div>
                                <Progression runs={runs} />
                                <div style={{ fontSize: '32px', marginTop: '1em', marginBottom: '0.5em' }}>Popularité</div>
                                <div style={{ width: '20vw' }}>
                                    <Progress percent={globalPop / 5} />
                                </div>
                                <div style={{ fontSize: '32px', marginTop: '0.5em' }}>{Math.round(globalPop)}/500</div>
                            </div>
                        </PlayContainerMid>
                        <PlayContainerBot>
                            <BottomBar>
                                <BottomBarContainer>
                                    <BottomBarRight>
                                        <Button
                                            onClick={() => {
                                                setShow(false);
                                            }}
                                            bordered={false}
                                            variation="success"
                                        >
                                            Démarrer
                                        </Button>
                                    </BottomBarRight>
                                </BottomBarContainer>
                            </BottomBar>
                        </PlayContainerBot>
                    </PlayContainer>
                </div>
            )}
        </Transition>
    );
};
