import { Reducer } from 'redux';
import { EndEffect } from '../models/PlayableCard';
import { Stats } from '../models/Stats';

/**
 * Une course, avec son score
 */
export interface Run {
    score?: number;
    done: boolean;
}

/**
 * État communs du jeu
 */
export interface AppState {
    /**
     * Stats actuelles
     */
    stats: Stats;
    /**
     * Effets de la course en cours
     */
    current_effects: EndEffect[];

    runs: Run[];
}

/**
 * État initiaux du jeu
 */
const initialState: AppState = {
    stats: {
        run: 0,
        reputation: 0
    },
    runs: [{ done: false }, { done: false }],
    current_effects: []
};

/**
 * Reducer avec gestion de la réinitialisation
 * @param state État actuel
 * @param action Action à effectuer
 * @returns État modifié
 */
export const rootReducer: Reducer = (state: AppState | undefined = JSON.parse(JSON.stringify(initialState)), action = { type: '' }) => {
    if (action.type === 'stats/reset') {
        state = undefined;
    }

    return appReducer(state, action);
};

/**
 * Réducer. Reçoit des actions et agit en conséquence sur les états du jeu
 * @param state État actuel
 * @param action Action à effectuer
 * @returns État modifié
 */
export const appReducer: Reducer = (state: AppState = JSON.parse(JSON.stringify(initialState)), action = { type: '' }) => {
    switch (action.type) {
        case 'stats/run':
            state.runs[state.stats.run].done = true;
            state.runs[state.stats.run].score = action.score;
            state.stats.run += 1;
            break;
        case 'state/reputation':
            state.stats.reputation += action.reputation;
            state.stats.reputation = Math.max(Math.min(state.stats.reputation, 500), 0);
            break;
        case 'game/end':
            state.current_effects = action.effects;
            break;
        default:
            break;
    }
    return state;
};
